<?php
/*-----------------------------------------------*/
/*  EXTHEM.ES
/*  PREMIUM WORDRESS THEMES
/*
/*  STOP DON'T TRY EDIT
/*  IF YOU DON'T KNOW PHP 
/*
/*  As Errors In Your Themes
/*  Are Not The Responsibility
/*  Of The DEVELOPERS
/*  @EXTHEM.ES
/*  
/*  Follow Social Media Exthem.es
/*  Youtube : https://www.youtube.com/channel/UCpcZNXk6ySLtwRSBN6fVyLA
/*  Facebook : https://www.facebook.com/groups/exthem.es
/*  Twitter : https://x.com/bangreyblog
/*  Instagram : https://www.instagram.com/exthem.es/
/*  Telegram : https://t.me/exthemes_helps
/*  TikTok : https://www.tiktok.com/@exthemes
/*	More Premium Themes Visit Now On https://exthem.es/
/*-----------------------------------------------*/
if ( ! defined( 'ABSPATH' ) ) exit; 
// Silence is golden.


 
if (!function_exists('ouo_io_exhemes')) {
	function ouo_io_exhemes($url) {
		$apikey		= 'mH4aOrLs'; 
		$url 		= "http://ouo.io/api/{$apikey}?s=".urlencode($url);
		$ch 		= curl_init();
		curl_setopt($ch, CURLOPT_URL, $url);
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, TRUE);
		curl_setopt($ch, CURLOPT_HEADER, FALSE);
		curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 0);
		curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, 0);
		$response 	= curl_exec($ch);
		curl_close($ch);
		$html 		= @file_get_contents($url);
		if( $html ){
			return $html;
		}
	}
}
 
if (!function_exists('adurl_exhemes')) {
	function adurl_exhemes($url) {
		$apikey		= 'd14c59dfb644f1f9f9aa0e4ad120fa7245db255b'; 
		//$urlx 		= "http://ouo.io/api/{$apikey}?s=".urlencode($url);
		$url	 	= "https://adurl.io/api?api={$apikey}&url={$url}&format=text";
		$ch 		= curl_init();
		curl_setopt($ch, CURLOPT_URL, $url);
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, TRUE);
		curl_setopt($ch, CURLOPT_HEADER, FALSE);
		curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 0);
		curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, 0);
		$response 	= curl_exec($ch);
		curl_close($ch);
		$html 		= @file_get_contents($url);
		if( $html ){
			return $html;
		}
	}
}

if (!function_exists('ouo_io_user')) {
	function ouo_io_user($url) {
		global $opt_themes;
		$apikey		= $opt_themes['ouo_apikey'];  
		$url 		= "http://ouo.io/api/{$apikey}?s=".urlencode($url);
		$ch 		= curl_init();
		curl_setopt($ch, CURLOPT_URL, $url);
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, TRUE);
		curl_setopt($ch, CURLOPT_HEADER, FALSE);
		curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 0);
		curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, 0);
		$response 	= curl_exec($ch);
		curl_close($ch);
		$html 		= @file_get_contents($url);
		if( $html ){
			return $html;
		}
	}
}

if (!function_exists('shrinkearn_exhemes')) {
	function shrinkearn_exhemes($url) {
		$apikey		= '3e0539585e9287452cd46529df428fd8f166a6f8'; 
		//$url 		= "http://ouo.io/api/{$apikey}?s=".urlencode($url);
		$url	 	= "https://shrinkearn.com/api?api={$apikey}&url={$url}&format=text";
		$ch 		= curl_init();
		curl_setopt($ch, CURLOPT_URL, $url);
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, TRUE);
		curl_setopt($ch, CURLOPT_HEADER, FALSE);
		curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 0);
		curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, 0);
		$response 	= curl_exec($ch);
		curl_close($ch);
		$html 		= @file_get_contents($url);
		if( $html ){
			return $html;
		}
	}
}

if (!function_exists('shrinkearn_user')) {
	function shrinkearn_user($url) {
		global $opt_themes;
		$apikey		= $opt_themes['shrinkearn_apikey'];  
		//$urlx 		= "http://ouo.io/api/{$apikey}?s=".urlencode($url);
		$url	 	= "https://shrinkearn.com/api?api={$apikey}&url={$url}&format=text";
		$ch 		= curl_init();
		curl_setopt($ch, CURLOPT_URL, $url);
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, TRUE);
		curl_setopt($ch, CURLOPT_HEADER, FALSE);
		curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 0);
		curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, 0);
		$response 	= curl_exec($ch);
		curl_close($ch);
		$html 		= @file_get_contents($url);
		if( $html ){
			return $html;
		}
	}
}
 
if (!function_exists('paid4link_user')) {
	function paid4link_user($url) {
		global $opt_themes;
		$apikey		= $opt_themes['paid4link_apikey'];  
		//$urlx 		= "http://adurl.io/api/{$apikey}?s=".urlencode($url);
		//$api_url 	= "https://paid4link.com/api?api={$api_token}&url={$long_url}&alias=CustomAlias&format=text";
		$url	 	= "https://paid4link.com/api?api={$apikey}&url={$url}&format=text";
		$ch 		= curl_init();
		curl_setopt($ch, CURLOPT_URL, $url);
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, TRUE);
		curl_setopt($ch, CURLOPT_HEADER, FALSE);
		curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 0);
		curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, 0);
		$response 	= curl_exec($ch);
		curl_close($ch);
		$html 		= @file_get_contents($url);
		//$html 		= scrapedo($url);
		if( $html ){
			return $html;
		}
	}
}

if (!function_exists('adurl_user')) {
	function adurl_user($url) {
		global $opt_themes;
		$apikey		= $opt_themes['adurl_apikey'];  
		//$urlx 		= "http://adurl.io/api/{$apikey}?s=".urlencode($url);
		$url	 	= "https://adurl.io/api?api={$apikey}&url={$url}&format=text";
		$ch 		= curl_init();
		curl_setopt($ch, CURLOPT_URL, $url);
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, TRUE);
		curl_setopt($ch, CURLOPT_HEADER, FALSE);
		curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 0);
		curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, 0);
		$response 	= curl_exec($ch);
		curl_close($ch);
		$html 		= @file_get_contents($url);
		if( $html ){
			return $html;
		}
	}
}